(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      6010,        165]
NotebookOptionsPosition[      5643,        148]
NotebookOutlinePosition[      5989,        163]
CellTagsIndexPosition[      5946,        160]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "The Heat Equation \n",
 StyleBox["(1 term solution)",
  FontSize->12],
 "\nFor a rod of lenght \"1\" initially at 100 units set in a bath of 0 \
degree fluid.  \[LineSeparator]Ends are exposed but the body of the rod is \
perfectly insulated.  "
}], "Text",
 CellFrame->{{0.5, 3}, {3, 0.5}},
 CellFrameColor->RGBColor[0, 0, 1],
 CellChangeTimes->{{3.495919133137974*^9, 3.4959192229783735`*^9}, {
  3.495919525275174*^9, 3.495919574087574*^9}, {3.495919775140689*^9, 
  3.495919780179941*^9}},
 TextAlignment->Center,
 FontFamily->"Arial",
 FontSize->16,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"l", "=", "1"}], ";", "\[IndentingNewLine]", 
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        FractionBox["400", "\[Pi]"], ")"}], 
       RowBox[{"Sin", "[", 
        FractionBox[
         RowBox[{"\[Pi]", "*", "x"}], "l"], "]"}], "*", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "k"}], 
         SuperscriptBox[
          RowBox[{"(", 
           FractionBox["\[Pi]", "l"], ")"}], "2"], "t"}]]}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "2"}], "}"}], ",", 
      RowBox[{"FaceGrids", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "150"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Length\>\"", ",", "\"\<Time\>\"", ",", " ", 
         "\"\<Temperature\>\""}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"500", ",", "500"}], "}"}]}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", ".1", ",", "\"\<Conductivity\>\""}], "}"}], ",", 
     ".01", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", ":>", 
    RowBox[{"{", "k", "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4888933453898387`*^9, 3.488893452784588*^9}, {
   3.4888934864577556`*^9, 3.488893526678241*^9}, {3.4888938131910763`*^9, 
   3.48889383025434*^9}, 3.488894137986876*^9, {3.488894175394802*^9, 
   3.4888941876609764`*^9}, {3.488894294822027*^9, 3.488894343824222*^9}, {
   3.4888963085216117`*^9, 3.4888963245379543`*^9}, 3.48889641987035*^9, {
   3.4959194677267737`*^9, 3.495919504464774*^9}, {3.495919587066774*^9, 
   3.4959195980647993`*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 0.025, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`k$$], 0.1, "Conductivity"}, 0.01, 1}}, 
    Typeset`size$$ = {500., {248., 252.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`k$31218$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, "Variables" :> {$CellContext`k$$ = 0.1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`k$$, $CellContext`k$31218$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`l = 1; 
       Plot3D[((400/Pi) Sin[Pi ($CellContext`x/$CellContext`l)]) 
         E^(((-$CellContext`k$$) (
              Pi/$CellContext`l)^2) $CellContext`t), {$CellContext`x, 0, 
          1}, {$CellContext`t, 0, 2}, FaceGrids -> All, 
         PlotRange -> {{0, 1}, {0, 2}, {0, 150}}, 
         AxesLabel -> {"Length", "Time", "Temperature"}, 
         ImageSize -> {500, 500}]), 
      "Specifications" :> {{{$CellContext`k$$, 0.1, "Conductivity"}, 0.01, 1, 
         Appearance -> "Labeled", ImageSize -> Tiny}}, 
      "Options" :> {TrackedSymbols :> {$CellContext`k$$}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{545., {289., 294.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.4888943568248043`*^9, 3.4888944174993973`*^9, {3.4888963124905396`*^9, 
   3.4888963249285965`*^9}, 3.4888964220735736`*^9, 3.4959195054475737`*^9, 
   3.4959195988292675`*^9}]
}, {2}]]
},
WindowSize->{767, 750},
WindowMargins->{{132, Automatic}, {Automatic, 21}},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 593, 16, 114, "Text"],
Cell[CellGroupData[{
Cell[1163, 40, 2281, 58, 191, "Input"],
Cell[3447, 100, 2183, 45, 600, "Output"]
}, {2}]]
}
]
*)

(* End of internal cache information *)
