(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[      8291,        213]
NotebookOptionsPosition[      7924,        196]
NotebookOutlinePosition[      8270,        211]
CellTagsIndexPosition[      8227,        208]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 "The Heat Equation \n",
 StyleBox["(multiple terms term solution)",
  FontSize->12],
 "\nFor a rod of lenght \"1\" initially at 100 units set in a bath of 0 \
degree fluid.  \[LineSeparator]Ends are exposed but the body of the rod is \
perfectly insulated.  "
}], "Text",
 CellFrame->{{0.5, 3}, {3, 0.5}},
 CellFrameColor->RGBColor[0, 0, 1],
 CellChangeTimes->{{3.495919133137974*^9, 3.4959192229783735`*^9}, {
  3.495919525275174*^9, 3.495919574087574*^9}, {3.495919775140689*^9, 
  3.495919780179941*^9}, {3.495920364753272*^9, 3.495920368211322*^9}},
 TextAlignment->Center,
 FontFamily->"Arial",
 FontSize->16,
 FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"l", "=", "1"}], ";", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x_", ",", "t_"}], "]"}], ":=", 
     RowBox[{"NSum", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         FractionBox["400", 
          RowBox[{"n", "*", "\[Pi]"}]], ")"}], 
        RowBox[{"Sin", "[", 
         FractionBox[
          RowBox[{"n", "*", "\[Pi]", "*", "x"}], "l"], "]"}], 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "k"}], 
          SuperscriptBox[
           RowBox[{"(", 
            FractionBox[
             RowBox[{"n", "*", "\[Pi]"}], "l"], ")"}], "2"], "t"}]]}], " ", 
       ",", 
       RowBox[{"{", 
        RowBox[{"n", ",", "1", ",", "m", ",", "2"}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Plot3D", "[", 
     RowBox[{
      RowBox[{"f", "[", 
       RowBox[{"x", ",", "t"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "2"}], "}"}], ",", 
      RowBox[{"FaceGrids", "\[Rule]", "All"}], ",", 
      RowBox[{"PlotRange", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{"0", ",", "1"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "2"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "150"}], "}"}]}], "}"}]}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"Directive", "[", 
        RowBox[{"Orange", ",", 
         RowBox[{"Specularity", "[", 
          RowBox[{"White", ",", "30"}], "]"}]}], "]"}]}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", 
       RowBox[{"ControlActive", "[", 
        RowBox[{"4", ",", "20"}], "]"}]}], ",", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Length\>\"", ",", "\"\<Time\>\"", ",", " ", 
         "\"\<Temperature\>\""}], "}"}]}], ",", 
      RowBox[{"ImageSize", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"500", ",", "500"}], "}"}]}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"k", ",", ".1", ",", "\"\<Conductivity\>\""}], "}"}], ",", 
     ".01", ",", "1", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"m", ",", "1", ",", "\"\<Number of terms\>\""}], "}"}], ",", 
     "1", ",", "51", ",", "2", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "Tiny"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"TrackedSymbols", ":>", 
    RowBox[{"{", 
     RowBox[{"k", ",", "m"}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.488893600978444*^9, 3.4888936375894594`*^9}, {
   3.488893735359464*^9, 3.4888937743143344`*^9}, {3.4888938834754744`*^9, 
   3.488893910742321*^9}, {3.4888939685105343`*^9, 3.488893973260747*^9}, {
   3.4888940075122814`*^9, 3.4888940708744946`*^9}, {3.4888955522533574`*^9, 
   3.488895554503458*^9}, {3.4888956056619997`*^9, 3.488895617381275*^9}, {
   3.488896247503253*^9, 3.4888962716449594`*^9}, 3.488896439605609*^9, {
   3.4905460996804943`*^9, 3.490546212609618*^9}, {3.490546685645275*^9, 
   3.4905467030393867`*^9}, 3.4959204074960117`*^9}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`k$$ = 0.1, $CellContext`m$$ = 13, 
    Typeset`show$$ = True, Typeset`bookmarkList$$ = {}, 
    Typeset`bookmarkMode$$ = "Menu", Typeset`animator$$, Typeset`animvar$$ = 
    1, Typeset`name$$ = "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`k$$], 0.1, "Conductivity"}, 0.01, 1}, {{
       Hold[$CellContext`m$$], 1, "Number of terms"}, 1, 51, 2}}, 
    Typeset`size$$ = {500., {248., 252.}}, Typeset`update$$ = 0, 
    Typeset`initDone$$, Typeset`skipInitDone$$ = 
    True, $CellContext`k$82434$$ = 0, $CellContext`m$82435$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`k$$ = 0.1, $CellContext`m$$ = 1}, 
      "ControllerVariables" :> {
        Hold[$CellContext`k$$, $CellContext`k$82434$$, 0], 
        Hold[$CellContext`m$$, $CellContext`m$82435$$, 0]}, 
      "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`l = 1; $CellContext`f[
          Pattern[$CellContext`x$, 
           Blank[]], 
          Pattern[$CellContext`t$, 
           Blank[]]] := 
        NSum[((400/($CellContext`n Pi)) 
           Sin[($CellContext`n Pi) ($CellContext`x$/$CellContext`l)]) 
          E^(((-$CellContext`k$$) ($CellContext`n (
                Pi/$CellContext`l))^2) $CellContext`t$), {$CellContext`n, 
           1, $CellContext`m$$, 2}]; Plot3D[
         $CellContext`f[$CellContext`x, $CellContext`t], {$CellContext`x, 0, 
          1}, {$CellContext`t, 0, 2}, FaceGrids -> All, 
         PlotRange -> {{0, 1}, {0, 2}, {0, 150}}, PlotStyle -> 
         Directive[Orange, 
           Specularity[White, 30]], PlotPoints -> ControlActive[4, 20], 
         AxesLabel -> {"Length", "Time", "Temperature"}, 
         ImageSize -> {500, 500}]), 
      "Specifications" :> {{{$CellContext`k$$, 0.1, "Conductivity"}, 0.01, 1, 
         Appearance -> "Labeled", ImageSize -> 
         Tiny}, {{$CellContext`m$$, 1, "Number of terms"}, 1, 51, 2, 
         Appearance -> "Labeled", ImageSize -> Tiny}}, 
      "Options" :> {TrackedSymbols :> {$CellContext`k$$, $CellContext`m$$}}, 
      "DefaultOptions" :> {}],
     ImageSizeCache->{545., {299., 304.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.4888937824709496`*^9, 3.488893923258507*^9, 3.4888939739326515`*^9, {
   3.488894026075613*^9, 3.4888940716714053`*^9}, 3.4888955556910114`*^9, 
   3.4888956185375767`*^9, {3.4888962504565105`*^9, 3.488896272285613*^9}, 
   3.488896440699408*^9, {3.4905461010221033`*^9, 3.490546119820224*^9}, {
   3.4905461695377426`*^9, 3.490546214325629*^9}, {3.490546687283285*^9, 
   3.4905467039909925`*^9}, 3.4959204091315756`*^9}]
}, {2}]]
},
WindowSize->{780, 750},
WindowMargins->{{138, Automatic}, {70, Automatic}},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[545, 20, 652, 16, 114, "Text"],
Cell[CellGroupData[{
Cell[1222, 40, 3480, 89, 224, "Input"],
Cell[4705, 131, 3206, 62, 620, "Output"]
}, {2}]]
}
]
*)

(* End of internal cache information *)
